<?php
/*
Plugin Name: Afiliado
Description: Cria produtos no WooCommerce a partir de dados do Mercado Livre.
Version: 1.1
Author: Clube Vitrine Digital
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

function mlb_product_creator_menu() {
    // Adiciona o menu principal "Painel do Plugin"
    add_menu_page(
        'Painel do Plugin', 
        'Painel do Plugin', 
        'manage_options', 
        'mlb-product-creator-panel', 
        'mlb_product_creator_page', 
        'dashicons-admin-generic', // Ícone para o menu "Painel do Plugin"
        20 // Posição do menu
    );

    // Adiciona o submenu de login sob o menu principal
    add_submenu_page(
        'mlb-product-creator-panel',
        'Loja Afiliado Mercado Livre',
        'Loja Afiliado Mercado Livre',
        'manage_options',
        'mlb-product-creator',
        'mlb_login_form_page'
    );
    
    // Adiciona o submenu "Produtos" que redireciona para a tela de todos os produtos do WooCommerce
    add_submenu_page(
        'mlb-product-creator-panel',
        'Produtos',
        'Produtos',
        'manage_options',
        'mlb-product-creator-products',
        'mlb_redirect_to_woocommerce_products'
    );
}
add_action('admin_menu', 'mlb_product_creator_menu');

// Função para redirecionar para a página de produtos do WooCommerce
function mlb_redirect_to_woocommerce_products() {
    wp_redirect(admin_url('edit.php?post_type=product'));
    exit;
}

// Função para exibir o formulário de login no menu do plugin
function mlb_login_form_page() {
    if (isset($_POST['login'])) {
        $email = sanitize_email($_POST['email']);
        if (mlb_verify_email($email)) {
            update_option('mlb_user_email', $email);
            update_option('mlb_last_login_time', time());
            ?>
            <div class="wrap">
                <h1>Login bem-sucedido</h1>
                <p>Você está logado com sucesso. Vá para o painel do plugin para continuar.</p>
                <a href="<?php echo admin_url('admin.php?page=mlb-product-creator-panel'); ?>" class="button">Ir para o Painel do Plugin</a>
            </div>
            <?php
            return;
        } else {
            ?>
            <div class="wrap">
                <h1>Erro de Login</h1>
                <p>Email não autorizado. Por favor, compre o acesso ou tente novamente.</p>
                <a href="./plugin" target="_blank">Comprar Acesso Agora!</a>
                <br><br>
                <a href="<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>" class="button">Voltar para Login</a>
            </div>
            <?php
            return;
        }
    }
    ?>
    <div class="wrap">
        <h1>Login</h1>
        <form method="post" action="">
            <label for="email">Email:</label>
            <input type="email" id="email" name="email" required>
            <br><br>
            <input type="submit" name="login" value="Entrar">
        </form>
        <div class="support-info">
            Dúvidas? Email de suporte: <a href="mailto:contato@melidados.com.br">contato@melidados.com.br</a>
        </div>
    </div>
    <?php
}

// Função para exibir a página do plugin no menu do plugin
function mlb_product_creator_page() {
    if (isset($_POST['logout'])) {
        delete_option('mlb_user_email');
        delete_option('mlb_last_login_time');
        ?>
        <div class="wrap">
            <h1>MLB Product Creator</h1>
            <div class="updated notice">
                <p>Você saiu com sucesso. Por favor, insira o email novamente para acessar o plugin.</p>
            </div>
            <a href="<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>">Entrar</a>
            <script>
                setTimeout(function() {
                    window.location.href = "<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>";
                }, 1000); // Redireciona após 1 segundo
            </script>
        </div>
        <?php
        return;
    }

    // Verificação e deslogamento automático após 12 horas
    $last_login_time = get_option('mlb_last_login_time', 0);
    $current_time = time();
    $hours_difference = ($current_time - $last_login_time) / (60 * 60); // Diferença em horas

    if ($last_login_time && $hours_difference >= 12) {
        delete_option('mlb_user_email');
        delete_option('mlb_last_login_time');
        ?>
        <div class="wrap">
            <h1>MLB Product Creator</h1>
            <div class="updated notice">
                <p>Você foi deslogado automaticamente por inatividade. Por favor, insira o email novamente para acessar o plugin.</p>
            </div>
            <a href="<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>">Entrar</a>
            <script>
                setTimeout(function() {
                    window.location.href = "<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>";
                }, 1000); // Redireciona após 1 segundo
            </script>
        </div>
        <?php
        return;
    }

    $email = get_option('mlb_user_email', '');

    if (!$email || !mlb_verify_email($email)) {
        ?>
        <div class="wrap">
            <h1>MLB Product Creator</h1>
            <?php if (!$email) { ?>
                <p>Por favor, insira o email que comprou o acesso ao plugin para utilizá-lo!</p>
                <a href="<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>">Entrar</a>
            <?php } else { ?>
                <p>Seu email não é autorizado a usar este plugin. Por favor, compre o acesso.</p>
                <a href="./plugin" target="_blank">Comprar Acesso Agora!</a>
                <br><br>
                <a href="<?php echo admin_url('admin.php?page=mlb-product-creator'); ?>" class="button">Tentar Novamente</a>
            <?php } ?>
        </div>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                document.querySelector('.wrap').classList.add('show');
            });
        </script>
        <?php
        return;
    }

    // Atualiza o timestamp do último login
    update_option('mlb_last_login_time', time());

    if (isset($_POST['submit'])) {
        $mlb_id = sanitize_text_field($_POST['mlb']);
        $affiliate_link = sanitize_text_field($_POST['affiliate_link']);
        mlb_create_product($mlb_id, $affiliate_link);
    }

    // Exibindo formulário principal após validação do email
    ?>
    <div class="wrap">
        <h1>MLB Product Creator</h1>
        <form method="post" action="">
            <p>Email validado com sucesso!</p>
            <input type="submit" name="logout" class="button" value="Deslogar">
        </form>
        <form method="post" action="">
            <label for="mlb">Link do Produto:</label>
            <input type="text" id="mlb" name="mlb" required>
            <br><br>
            <label for="affiliate_link">Link Afiliado:</label>
            <input type="text" id="affiliate_link" name="affiliate_link" required>
            <br><br>
            <input type="submit" name="submit" value="Enviar">
        </form>
    </div>
    <div class="support-info">
    Dúvidas? Email de suporte: <a href="mailto:contato@melidados.com.br">contato@melidados.com.br</a>
    </div>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            document.querySelector('.wrap').classList.add('show');
        });
    </script>
    
    <?php
if (isset($_POST['submit'])) {
    $mlb_id = $_POST['mlb'];
    $affiliate_link = $_POST['affiliate_link'];

    $mlb_produto = extrairMLB($mlb_id);
    
    //echo '<pre>';
        //echo 'MLB Produto: ' . htmlspecialchars($mlb_produto);
        //echo '</pre>';

    if ($mlb_produto) {
        mlb_create_product($mlb_produto, $affiliate_link);
    } 
}
}

// Função para verificar o email
function mlb_verify_email($email) {
    $response = wp_remote_get("https://melidados.com.br/sistema-plugin/verificacao-usuario.php?email=" . urlencode($email));
    
    if (is_wp_error($response)) {
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return isset($data['authorized']) && $data['authorized'];
}

function extrairMLB($mlb_id) {
    // Verificar se há 'item_id:' na URL
    if (strpos($mlb_id, 'item_id:') !== false) {
        // Extrair o valor após 'item_id:' e antes de '#'
        preg_match('/item_id:([^#]*)#/', $mlb_id, $matches);
        if (isset($matches[1])) {
            return $matches[1];
        }
    } 
    
    // Caso não tenha 'item_id:', procurar por 'MLB' e extrair conforme a segunda regra
    if (strpos($mlb_id, 'MLB-') !== false) {
        // Ajustar a expressão regular para capturar 'MLB' seguido de dígitos até o próximo traço
        preg_match('/(MLB-\d+)/', $mlb_id, $matches);
        if (isset($matches[0])) {
            // Remover o traço para retornar somente 'MLB' seguido dos dígitos
            return str_replace('-', '', $matches[0]);
        }
    }
    
    // Terceiro caso: Extrair informações da página HTML
    
    if (strpos($mlb_id, 'MLB') !== false) {
    $html = file_get_contents($mlb_id);

        if ($html === false) {
            return null;
        }
    

    $dom = new DOMDocument();
    @$dom->loadHTML($html);
    $xpath = new DOMXPath($dom);

    // Obter o título
    $titleNode = $xpath->query("//h1[contains(@class, 'ui-pdp-title')]");
    $title = $titleNode->length > 0 ? trim($titleNode->item(0)->nodeValue) : null;

    // Definir a categoria como 'ofertas'
    $category_name = 'Ofertas';

    // Obter a imagem
    $imageNode = $xpath->query("//figure[contains(@class, 'ui-pdp-gallery__figure')]//img[contains(@class, 'ui-pdp-image')]");
    $image_src = $imageNode->length > 0 ? $imageNode->item(0)->getAttribute('data-zoom') : null;
    //echo "URL da Imagem: " . ($image_src ? $image_src : "Não encontrada");

    // Criar o produto no WooCommerce se os dados necessários foram encontrados
    if ($title && $image_src) {
        $affiliate_link = $_POST['affiliate_link']; // Link do produto no Mercado Livre
        mlb_create_product_from_html($title, $category_name, $image_src, $affiliate_link);
    } else {
        return null;
    }

    return null;
    }
}   

// Função para criar o produto no WooCommerce a partir dos dados extraídos do HTML
function mlb_create_product_from_html($title, $category_name, $image_src, $affiliate_link) {
    // Criar ou obter a categoria no WooCommerce
    $category_id = mlb_create_or_get_category($category_name);

    $product = new WC_Product_External();
    $product->set_name($title);
    $product->set_description('<br><a href="' . esc_url($affiliate_link) . '">Ver mais detalhes no Mercado Livre</a>');
    $product->set_product_url($affiliate_link);
    $product->set_button_text('VER AGORA NO MERCADO LIVRE!');
    $product->set_image_id(mlb_upload_image($image_src));
    $product->set_category_ids(array($category_id));

    $product_id = $product->save();

    if ($product_id) {
        echo 'Produto criado com sucesso: ' . $title;
    } else {
        echo 'Erro ao criar o produto.';
    }
}

// Função para buscar dados do Mercado Livre e criar o produto no WooCommerce
function mlb_create_product($mlb_produto, $affiliate_link) {
    $response = wp_remote_get("https://api.mercadolibre.com/items/" . $mlb_produto);
    
    //echo "$mlb_produto";

    if (is_wp_error($response)) {
        echo 'Erro na requisição: ' . $response->get_error_message();
        return;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (empty($data) || isset($data['error'])) {
        echo '';
        return;
    }

    $title = sanitize_text_field($data['title']);
    $pictures = $data['pictures'];
    $thumbnail = isset($pictures[0]['url']) ? esc_url($pictures[0]['url']) : '';

    if (empty($thumbnail)) {
        echo 'Imagem do produto não encontrada.';
        return;
    }
    
    // Obter a categoria do produto
    $category_id = sanitize_text_field($data['category_id']);
    $category_name = mlb_get_category_name($category_id);

    // Criar ou obter a categoria no WooCommerce
    $category_id = mlb_create_or_get_category($category_name);

    $product = new WC_Product_External();
    $product->set_name($title);
    $product->set_description('<br><a href="' . esc_url($affiliate_link) . '">Ver mais detalhes no Mercado Livre</a>');
    $product->set_product_url($affiliate_link);
    $product->set_button_text('VER AGORA NO MERCADO LIVRE!');
    $product->set_image_id(mlb_upload_image($thumbnail));
    $product->set_category_ids(array($category_id));

    $product_id = $product->save();

    if ($product_id) {
        echo 'Produto criado com sucesso: ' . $title . ' ' . htmlspecialchars($mlb_produto);

    } else {
        echo 'Erro ao criar o produto.';
    }
}

// Função para fazer o upload da imagem do produto
function mlb_upload_image($image_url) {
    $upload_dir = wp_upload_dir();
    $image_data = file_get_contents($image_url);
    $filename = basename($image_url);

    if (wp_mkdir_p($upload_dir['path'])) {
        $file = $upload_dir['path'] . '/' . $filename;
    } else {
        $file = $upload_dir['basedir'] . '/' . $filename;
    }

    file_put_contents($file, $image_data);

    $wp_filetype = wp_check_filetype($filename, null);
    $attachment = array(
        'post_mime_type' => $wp_filetype['type'],
        'post_title' => sanitize_file_name($filename),
        'post_content' => '',
        'post_status' => 'inherit'
    );

    $attach_id = wp_insert_attachment($attachment, $file);
    require_once(ABSPATH . 'wp-admin/includes/image.php');
    $attach_data = wp_generate_attachment_metadata($attach_id, $file);
    wp_update_attachment_metadata($attach_id, $attach_data);

    return $attach_id;
}

// Função para obter o nome da categoria a partir do category_id
function mlb_get_category_name($category_id) {
    $response = wp_remote_get("https://api.mercadolibre.com/categories/$category_id");

    if (is_wp_error($response)) {
        return '';
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (empty($data) || isset($data['error'])) {
        return '';
    }

    return sanitize_text_field($data['name']);
}

// Função para criar ou obter a categoria no WooCommerce
function mlb_create_or_get_category($category_name) {
    if (term_exists($category_name, 'product_cat')) {
        $term = get_term_by('name', $category_name, 'product_cat');
        return $term->term_id;
    } else {
        $term = wp_insert_term($category_name, 'product_cat');
        if (is_wp_error($term)) {
            return 0; // Erro ao criar a categoria
        }
        return $term['term_id'];
    }
}


?>
